/*
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s): 
 *      Blake Ross <BlakeR1234@aol.com>
 */

@namespace url(http://www.w3.org/1999/xhtml); /* set default namespace to HTML */

html {
  background-color: window;
}
.viewsource {
  font-family: monospace;
  font-weight: normal;
  color: windowtext;
  white-space: pre;
  font-size: 12px;
  padding-top: 8px; 
  margin-left: 8px;
}
.start-tag {
 color: purple;
 font-weight: bold;
}
.end-tag {
 color: purple;
 font-weight: bold; 
}
.comment {
 color: green;
 font-style: italic;
}
.cdata {
 color: #CC0066;
}
.doctype {
 color: steelblue;
 font-style: italic;
}
.pi {
 color: orchid;
 font-style: italic;
}
.entity {
 color:#FF4500;
 font-weight: normal;
}
.text {
  font-weight: normal;
}
.attribute-name {
 color: black;
 font-weight: bold;
}
.attribute-value {
 color: blue;
 font-weight: normal;
}
.summary {
 display: block;
 background-color: #FFFFCC;
 width: 90%;
 border: solid;
 border-width: 1pt;
 font-family: sans-serif;
}
.popup {
  font-weight: normal;
}
.markupdeclaration {
 color: steelblue;
 font-style: italic;
}
